==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/media/kotlin/inputs/VideoOverlayArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.inputs

import com.pulumi.azurenative.media.inputs.VideoOverlayArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Describes the properties of a video overlay.
 * @property audioGainLevel The gain level of audio in the overlay. The value should be in the range [0, 1&#46;0]. The default is 1.0.
 * @property cropRectangle An optional rectangular window used to crop the overlay image or video.
 * @property end The end position, with reference to the input video, at which the overlay ends. The value should be in ISO 8601 format. For example, PT30S to end the overlay at 30 seconds into the input video. If not specified or the value is greater than the input video duration, the overlay will be applied until the end of the input video if the overlay media duration is greater than the input video duration, else the overlay will last as long as the overlay media duration.
 * @property fadeInDuration The duration over which the overlay fades in onto the input video. The value should be in ISO 8601 duration format. If not specified the default behavior is to have no fade in (same as PT0S).
 * @property fadeOutDuration The duration over which the overlay fades out of the input video. The value should be in ISO 8601 duration format. If not specified the default behavior is to have no fade out (same as PT0S).
 * @property inputLabel The label of the job input which is to be used as an overlay. The Input must specify exactly one file. You can specify an image file in JPG, PNG, GIF or BMP format, or an audio file (such as a WAV, MP3, WMA or M4A file), or a video file. See https://aka.ms/mesformats for the complete list of supported audio and video file formats.
 * @property odataType The discriminator for derived types.
 * Expected value is '#Microsoft.Media.VideoOverlay'.
 * @property opacity The opacity of the overlay. This is a value in the range [0 - 1&#46;0]. Default is 1.0 which mean the overlay is opaque.
 * @property position The location in the input video where the overlay is applied.
 * @property start The start position, with reference to the input video, at which the overlay starts. The value should be in ISO 8601 format. For example, PT05S to start the overlay at 5 seconds into the input video. If not specified the overlay starts from the beginning of the input video.
 */
public data class VideoOverlayArgs(
    public val audioGainLevel: Output<Double>? = null,
    public val cropRectangle: Output<RectangleArgs>? = null,
    public val end: Output<String>? = null,
    public val fadeInDuration: Output<String>? = null,
    public val fadeOutDuration: Output<String>? = null,
    public val inputLabel: Output<String>,
    public val odataType: Output<String>,
    public val opacity: Output<Double>? = null,
    public val position: Output<RectangleArgs>? = null,
    public val start: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.media.inputs.VideoOverlayArgs> {
    override fun toJava(): com.pulumi.azurenative.media.inputs.VideoOverlayArgs =
        com.pulumi.azurenative.media.inputs.VideoOverlayArgs.builder()
            .audioGainLevel(audioGainLevel?.applyValue({ args0 -> args0 }))
            .cropRectangle(cropRectangle?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .end(end?.applyValue({ args0 -> args0 }))
            .fadeInDuration(fadeInDuration?.applyValue({ args0 -> args0 }))
            .fadeOutDuration(fadeOutDuration?.applyValue({ args0 -> args0 }))
            .inputLabel(inputLabel.applyValue({ args0 -> args0 }))
            .odataType(odataType.applyValue({ args0 -> args0 }))
            .opacity(opacity?.applyValue({ args0 -> args0 }))
            .position(position?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .start(start?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VideoOverlayArgs].
 */
@PulumiTagMarker
public class VideoOverlayArgsBuilder internal constructor() {
    private var audioGainLevel: Output<Double>? = null

    private var cropRectangle: Output<RectangleArgs>? = null

    private var end: Output<String>? = null

    private var fadeInDuration: Output<String>? = null

    private var fadeOutDuration: Output<String>? = null

    private var inputLabel: Output<String>? = null

    private var odataType: Output<String>? = null

    private var opacity: Output<Double>? = null

    private var position: Output<RectangleArgs>? = null

    private var start: Output<String>? = null

    /**
     * @param value The gain level of audio in the overlay. The value should be in the range [0, 1&#46;0]. The default is 1.0.
     */
    @JvmName("lnwpwytmrfwaribl")
    public suspend fun audioGainLevel(`value`: Output<Double>) {
        this.audioGainLevel = value
    }

    /**
     * @param value An optional rectangular window used to crop the overlay image or video.
     */
    @JvmName("xhnlwkgcnqyarjrw")
    public suspend fun cropRectangle(`value`: Output<RectangleArgs>) {
        this.cropRectangle = value
    }

    /**
     * @param value The end position, with reference to the input video, at which the overlay ends. The value should be in ISO 8601 format. For example, PT30S to end the overlay at 30 seconds into the input video. If not specified or the value is greater than the input video duration, the overlay will be applied until the end of the input video if the overlay media duration is greater than the input video duration, else the overlay will last as long as the overlay media duration.
     */
    @JvmName("dalhbtbwtmvaqbmi")
    public suspend fun end(`value`: Output<String>) {
        this.end = value
    }

    /**
     * @param value The duration over which the overlay fades in onto the input video. The value should be in ISO 8601 duration format. If not specified the default behavior is to have no fade in (same as PT0S).
     */
    @JvmName("tfbnqrrgsxgfisws")
    public suspend fun fadeInDuration(`value`: Output<String>) {
        this.fadeInDuration = value
    }

    /**
     * @param value The duration over which the overlay fades out of the input video. The value should be in ISO 8601 duration format. If not specified the default behavior is to have no fade out (same as PT0S).
     */
    @JvmName("ggjiugjajelghtxq")
    public suspend fun fadeOutDuration(`value`: Output<String>) {
        this.fadeOutDuration = value
    }

    /**
     * @param value The label of the job input which is to be used as an overlay. The Input must specify exactly one file. You can specify an image file in JPG, PNG, GIF or BMP format, or an audio file (such as a WAV, MP3, WMA or M4A file), or a video file. See https://aka.ms/mesformats for the complete list of supported audio and video file formats.
     */
    @JvmName("hamucavlbivsylmh")
    public suspend fun inputLabel(`value`: Output<String>) {
        this.inputLabel = value
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.VideoOverlay'.
     */
    @JvmName("xhyuwmeaxisviudq")
    public suspend fun odataType(`value`: Output<String>) {
        this.odataType = value
    }

    /**
     * @param value The opacity of the overlay. This is a value in the range [0 - 1&#46;0]. Default is 1.0 which mean the overlay is opaque.
     */
    @JvmName("whjhfkgbwtisqbej")
    public suspend fun opacity(`value`: Output<Double>) {
        this.opacity = value
    }

    /**
     * @param value The location in the input video where the overlay is applied.
     */
    @JvmName("gbfbydarduxwrbqp")
    public suspend fun position(`value`: Output<RectangleArgs>) {
        this.position = value
    }

    /**
     * @param value The start position, with reference to the input video, at which the overlay starts. The value should be in ISO 8601 format. For example, PT05S to start the overlay at 5 seconds into the input video. If not specified the overlay starts from the beginning of the input video.
     */
    @JvmName("xcysjchiweseltce")
    public suspend fun start(`value`: Output<String>) {
        this.start = value
    }

    /**
     * @param value The gain level of audio in the overlay. The value should be in the range [0, 1&#46;0]. The default is 1.0.
     */
    @JvmName("ttcrhxkjpvhwlxes")
    public suspend fun audioGainLevel(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.audioGainLevel = mapped
    }

    /**
     * @param value An optional rectangular window used to crop the overlay image or video.
     */
    @JvmName("xaylksbxurtuchiu")
    public suspend fun cropRectangle(`value`: RectangleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cropRectangle = mapped
    }

    /**
     * @param argument An optional rectangular window used to crop the overlay image or video.
     */
    @JvmName("dqrouusiyavldkgb")
    public suspend fun cropRectangle(argument: suspend RectangleArgsBuilder.() -> Unit) {
        val toBeMapped = RectangleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.cropRectangle = mapped
    }

    /**
     * @param value The end position, with reference to the input video, at which the overlay ends. The value should be in ISO 8601 format. For example, PT30S to end the overlay at 30 seconds into the input video. If not specified or the value is greater than the input video duration, the overlay will be applied until the end of the input video if the overlay media duration is greater than the input video duration, else the overlay will last as long as the overlay media duration.
     */
    @JvmName("sgbyltioxcjyijce")
    public suspend fun end(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.end = mapped
    }

    /**
     * @param value The duration over which the overlay fades in onto the input video. The value should be in ISO 8601 duration format. If not specified the default behavior is to have no fade in (same as PT0S).
     */
    @JvmName("lvqjbslmyntxgbuc")
    public suspend fun fadeInDuration(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fadeInDuration = mapped
    }

    /**
     * @param value The duration over which the overlay fades out of the input video. The value should be in ISO 8601 duration format. If not specified the default behavior is to have no fade out (same as PT0S).
     */
    @JvmName("bsimcaxmiixxyydm")
    public suspend fun fadeOutDuration(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fadeOutDuration = mapped
    }

    /**
     * @param value The label of the job input which is to be used as an overlay. The Input must specify exactly one file. You can specify an image file in JPG, PNG, GIF or BMP format, or an audio file (such as a WAV, MP3, WMA or M4A file), or a video file. See https://aka.ms/mesformats for the complete list of supported audio and video file formats.
     */
    @JvmName("drbnqffxxjrkwucf")
    public suspend fun inputLabel(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.inputLabel = mapped
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.VideoOverlay'.
     */
    @JvmName("wugiugfjomybvywo")
    public suspend fun odataType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.odataType = mapped
    }

    /**
     * @param value The opacity of the overlay. This is a value in the range [0 - 1&#46;0]. Default is 1.0 which mean the overlay is opaque.
     */
    @JvmName("iukkndnvjclmcmet")
    public suspend fun opacity(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.opacity = mapped
    }

    /**
     * @param value The location in the input video where the overlay is applied.
     */
    @JvmName("brfiqrstjdthmoqj")
    public suspend fun position(`value`: RectangleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.position = mapped
    }

    /**
     * @param argument The location in the input video where the overlay is applied.
     */
    @JvmName("jocokvlqjfoerect")
    public suspend fun position(argument: suspend RectangleArgsBuilder.() -> Unit) {
        val toBeMapped = RectangleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.position = mapped
    }

    /**
     * @param value The start position, with reference to the input video, at which the overlay starts. The value should be in ISO 8601 format. For example, PT05S to start the overlay at 5 seconds into the input video. If not specified the overlay starts from the beginning of the input video.
     */
    @JvmName("dysyserilqdahumt")
    public suspend fun start(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.start = mapped
    }

    internal fun build(): VideoOverlayArgs = VideoOverlayArgs(
        audioGainLevel = audioGainLevel,
        cropRectangle = cropRectangle,
        end = end,
        fadeInDuration = fadeInDuration,
        fadeOutDuration = fadeOutDuration,
        inputLabel = inputLabel ?: throw PulumiNullFieldException("inputLabel"),
        odataType = odataType ?: throw PulumiNullFieldException("odataType"),
        opacity = opacity,
        position = position,
        start = start,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/media/kotlin/inputs/VideoOverlayArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.inputs

import com.pulumi.azurenative.media.inputs.VideoOverlayArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Describes the properties of a video overlay.
 * @property audioGainLevel The gain level of audio in the overlay. The value should be in the range [0, 1&#46;0]. The default is 1.0.
 * @property cropRectangle An optional rectangular window used to crop the overlay image or video.
 * @property end The end position, with reference to the input video, at which the overlay ends. The value should be in ISO 8601 format. For example, PT30S to end the overlay at 30 seconds into the input video. If not specified or the value is greater than the input video duration, the overlay will be applied until the end of the input video if the overlay media duration is greater than the input video duration, else the overlay will last as long as the overlay media duration.
 * @property fadeInDuration The duration over which the overlay fades in onto the input video. The value should be in ISO 8601 duration format. If not specified the default behavior is to have no fade in (same as PT0S).
 * @property fadeOutDuration The duration over which the overlay fades out of the input video. The value should be in ISO 8601 duration format. If not specified the default behavior is to have no fade out (same as PT0S).
 * @property inputLabel The label of the job input which is to be used as an overlay. The Input must specify exactly one file. You can specify an image file in JPG, PNG, GIF or BMP format, or an audio file (such as a WAV, MP3, WMA or M4A file), or a video file. See https://aka.ms/mesformats for the complete list of supported audio and video file formats.
 * @property odataType The discriminator for derived types.
 * Expected value is '#Microsoft.Media.VideoOverlay'.
 * @property opacity The opacity of the overlay. This is a value in the range [0 - 1&#46;0]. Default is 1.0 which mean the overlay is opaque.
 * @property position The location in the input video where the overlay is applied.
 * @property start The start position, with reference to the input video, at which the overlay starts. The value should be in ISO 8601 format. For example, PT05S to start the overlay at 5 seconds into the input video. If not specified the overlay starts from the beginning of the input video.
 */
public data class VideoOverlayArgs(
    public val audioGainLevel: Output<Double>? = null,
    public val cropRectangle: Output<RectangleArgs>? = null,
    public val end: Output<String>? = null,
    public val fadeInDuration: Output<String>? = null,
    public val fadeOutDuration: Output<String>? = null,
    public val inputLabel: Output<String>,
    public val odataType: Output<String>,
    public val opacity: Output<Double>? = null,
    public val position: Output<RectangleArgs>? = null,
    public val start: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.media.inputs.VideoOverlayArgs> {
    override fun toJava(): com.pulumi.azurenative.media.inputs.VideoOverlayArgs =
        com.pulumi.azurenative.media.inputs.VideoOverlayArgs.builder()
            .audioGainLevel(audioGainLevel?.applyValue({ args0 -> args0 }))
            .cropRectangle(cropRectangle?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .end(end?.applyValue({ args0 -> args0 }))
            .fadeInDuration(fadeInDuration?.applyValue({ args0 -> args0 }))
            .fadeOutDuration(fadeOutDuration?.applyValue({ args0 -> args0 }))
            .inputLabel(inputLabel.applyValue({ args0 -> args0 }))
            .odataType(odataType.applyValue({ args0 -> args0 }))
            .opacity(opacity?.applyValue({ args0 -> args0 }))
            .position(position?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .start(start?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VideoOverlayArgs].
 */
@PulumiTagMarker
public class VideoOverlayArgsBuilder internal constructor() {
    private var audioGainLevel: Output<Double>? = null

    private var cropRectangle: Output<RectangleArgs>? = null

    private var end: Output<String>? = null

    private var fadeInDuration: Output<String>? = null

    private var fadeOutDuration: Output<String>? = null

    private var inputLabel: Output<String>? = null

    private var odataType: Output<String>? = null

    private var opacity: Output<Double>? = null

    private var position: Output<RectangleArgs>? = null

    private var start: Output<String>? = null

    /**
     * @param value The gain level of audio in the overlay. The value should be in the range [0, 1&#46;0]. The default is 1.0.
     */
    @JvmName("oofuyrikfjjmrfij")
    public suspend fun audioGainLevel(`value`: Output<Double>) {
        this.audioGainLevel = value
    }

    /**
     * @param value An optional rectangular window used to crop the overlay image or video.
     */
    @JvmName("gsdyoulmocvlxjdw")
    public suspend fun cropRectangle(`value`: Output<RectangleArgs>) {
        this.cropRectangle = value
    }

    /**
     * @param value The end position, with reference to the input video, at which the overlay ends. The value should be in ISO 8601 format. For example, PT30S to end the overlay at 30 seconds into the input video. If not specified or the value is greater than the input video duration, the overlay will be applied until the end of the input video if the overlay media duration is greater than the input video duration, else the overlay will last as long as the overlay media duration.
     */
    @JvmName("oughawtxpermarqh")
    public suspend fun end(`value`: Output<String>) {
        this.end = value
    }

    /**
     * @param value The duration over which the overlay fades in onto the input video. The value should be in ISO 8601 duration format. If not specified the default behavior is to have no fade in (same as PT0S).
     */
    @JvmName("vmbpngyylpgemwbh")
    public suspend fun fadeInDuration(`value`: Output<String>) {
        this.fadeInDuration = value
    }

    /**
     * @param value The duration over which the overlay fades out of the input video. The value should be in ISO 8601 duration format. If not specified the default behavior is to have no fade out (same as PT0S).
     */
    @JvmName("scnlhvamclujuube")
    public suspend fun fadeOutDuration(`value`: Output<String>) {
        this.fadeOutDuration = value
    }

    /**
     * @param value The label of the job input which is to be used as an overlay. The Input must specify exactly one file. You can specify an image file in JPG, PNG, GIF or BMP format, or an audio file (such as a WAV, MP3, WMA or M4A file), or a video file. See https://aka.ms/mesformats for the complete list of supported audio and video file formats.
     */
    @JvmName("flnxvhuifmxxectl")
    public suspend fun inputLabel(`value`: Output<String>) {
        this.inputLabel = value
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.VideoOverlay'.
     */
    @JvmName("ydccrrsdjgsrtotj")
    public suspend fun odataType(`value`: Output<String>) {
        this.odataType = value
    }

    /**
     * @param value The opacity of the overlay. This is a value in the range [0 - 1&#46;0]. Default is 1.0 which mean the overlay is opaque.
     */
    @JvmName("ffwbfwejsussufpl")
    public suspend fun opacity(`value`: Output<Double>) {
        this.opacity = value
    }

    /**
     * @param value The location in the input video where the overlay is applied.
     */
    @JvmName("lvgbuaxhyaebskhx")
    public suspend fun position(`value`: Output<RectangleArgs>) {
        this.position = value
    }

    /**
     * @param value The start position, with reference to the input video, at which the overlay starts. The value should be in ISO 8601 format. For example, PT05S to start the overlay at 5 seconds into the input video. If not specified the overlay starts from the beginning of the input video.
     */
    @JvmName("ibfenwkklrllgmps")
    public suspend fun start(`value`: Output<String>) {
        this.start = value
    }

    /**
     * @param value The gain level of audio in the overlay. The value should be in the range [0, 1&#46;0]. The default is 1.0.
     */
    @JvmName("jiasiwgbxdlhxnaj")
    public suspend fun audioGainLevel(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.audioGainLevel = mapped
    }

    /**
     * @param value An optional rectangular window used to crop the overlay image or video.
     */
    @JvmName("uweaphcoljkmqgaf")
    public suspend fun cropRectangle(`value`: RectangleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cropRectangle = mapped
    }

    /**
     * @param argument An optional rectangular window used to crop the overlay image or video.
     */
    @JvmName("jxwwhghoerxqriga")
    public suspend fun cropRectangle(argument: suspend RectangleArgsBuilder.() -> Unit) {
        val toBeMapped = RectangleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.cropRectangle = mapped
    }

    /**
     * @param value The end position, with reference to the input video, at which the overlay ends. The value should be in ISO 8601 format. For example, PT30S to end the overlay at 30 seconds into the input video. If not specified or the value is greater than the input video duration, the overlay will be applied until the end of the input video if the overlay media duration is greater than the input video duration, else the overlay will last as long as the overlay media duration.
     */
    @JvmName("ihorttogwumstemh")
    public suspend fun end(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.end = mapped
    }

    /**
     * @param value The duration over which the overlay fades in onto the input video. The value should be in ISO 8601 duration format. If not specified the default behavior is to have no fade in (same as PT0S).
     */
    @JvmName("ynifspswxbnffrxb")
    public suspend fun fadeInDuration(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fadeInDuration = mapped
    }

    /**
     * @param value The duration over which the overlay fades out of the input video. The value should be in ISO 8601 duration format. If not specified the default behavior is to have no fade out (same as PT0S).
     */
    @JvmName("uhrgwvqufprihyed")
    public suspend fun fadeOutDuration(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fadeOutDuration = mapped
    }

    /**
     * @param value The label of the job input which is to be used as an overlay. The Input must specify exactly one file. You can specify an image file in JPG, PNG, GIF or BMP format, or an audio file (such as a WAV, MP3, WMA or M4A file), or a video file. See https://aka.ms/mesformats for the complete list of supported audio and video file formats.
     */
    @JvmName("rgcbjecknagqsrmq")
    public suspend fun inputLabel(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.inputLabel = mapped
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.VideoOverlay'.
     */
    @JvmName("vxgiswmeaqutbegw")
    public suspend fun odataType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.odataType = mapped
    }

    /**
     * @param value The opacity of the overlay. This is a value in the range [0 - 1&#46;0]. Default is 1.0 which mean the overlay is opaque.
     */
    @JvmName("epiqyxwnhbvotheh")
    public suspend fun opacity(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.opacity = mapped
    }

    /**
     * @param value The location in the input video where the overlay is applied.
     */
    @JvmName("ksixnedguqxdnbjj")
    public suspend fun position(`value`: RectangleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.position = mapped
    }

    /**
     * @param argument The location in the input video where the overlay is applied.
     */
    @JvmName("cmclelacultudjtm")
    public suspend fun position(argument: suspend RectangleArgsBuilder.() -> Unit) {
        val toBeMapped = RectangleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.position = mapped
    }

    /**
     * @param value The start position, with reference to the input video, at which the overlay starts. The value should be in ISO 8601 format. For example, PT05S to start the overlay at 5 seconds into the input video. If not specified the overlay starts from the beginning of the input video.
     */
    @JvmName("dlvylcjngrivcnvi")
    public suspend fun start(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.start = mapped
    }

    internal fun build(): VideoOverlayArgs = VideoOverlayArgs(
        audioGainLevel = audioGainLevel,
        cropRectangle = cropRectangle,
        end = end,
        fadeInDuration = fadeInDuration,
        fadeOutDuration = fadeOutDuration,
        inputLabel = inputLabel ?: throw PulumiNullFieldException("inputLabel"),
        odataType = odataType ?: throw PulumiNullFieldException("odataType"),
        opacity = opacity,
        position = position,
        start = start,
    )
}
